==> qtjambi-charts-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiCharts/QHBoxPlotModelMapper_shell.h <==
#ifndef QHBOXPLOTMODELMAPPER_SHELL_H
#define QHBOXPLOTMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCharts/qhboxplotmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QHBoxPlotModelMapper_shell : public QHBoxPlotModelMapper, public QtJambiShellInterface
{
public:
    QHBoxPlotModelMapper_shell(QObject* parent0 = nullptr);
    ~QHBoxPlotModelMapper_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHBoxPlotModelMapper_access : public QHBoxPlotModelMapper
{
};

#endif // QHBOXPLOTMODELMAPPER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiCharts/QHBoxPlotModelMapper_shell.h <==
#ifndef QHBOXPLOTMODELMAPPER_SHELL_H
#define QHBOXPLOTMODELMAPPER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qhboxplotmodelmapper.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qboxplotseries.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QHBoxPlotModelMapper_shell : public QHBoxPlotModelMapper, public QtJambiShellInterface
{
public:
    QHBoxPlotModelMapper_shell(QObject* parent0 = nullptr);
    ~QHBoxPlotModelMapper_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QHBoxPlotModelMapper_mshell;
    friend class QHBoxPlotModelMapper_oshell;
};


class QHBoxPlotModelMapper_mshell : public QHBoxPlotModelMapper_shell
{
public:
    using QHBoxPlotModelMapper_shell::QHBoxPlotModelMapper_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QHBoxPlotModelMapper_oshell : public QHBoxPlotModelMapper_mshell
{
public:
    using QHBoxPlotModelMapper_mshell::QHBoxPlotModelMapper_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QHBoxPlotModelMapper_access : public QHBoxPlotModelMapper
{
};

#endif // QHBOXPLOTMODELMAPPER_SHELL_H
